==> com.liferay.dynamic.data.mapping.form.web-3.0.42.jar: META-INF/resources/admin/js/components/PublishButton/PublishButton.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-web@3.0.42/admin/js/components/PublishButton/PublishButton.es", ['module', 'exports', 'require', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-jsx', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = void 0;

    var _clayButton = _interopRequireDefault(require("frontend-taglib-clay$clay-button"));

    var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

    var _metalState = require("frontend-js-metal-web$metal-state");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    function _possibleConstructorReturn(self, call) {
      if (call && (_typeof(call) === "object" || typeof call === "function")) {
        return call;
      }return _assertThisInitialized(self);
    }

    function _assertThisInitialized(self) {
      if (self === void 0) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
      }return self;
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };return _getPrototypeOf(o);
    }

    function _inherits(subClass, superClass) {
      if (typeof superClass !== "function" && superClass !== null) {
        throw new TypeError("Super expression must either be null or a function");
      }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
        o.__proto__ = p;return o;
      };return _setPrototypeOf(o, p);
    }

    var PublishButton = /*#__PURE__*/function (_Component) {
      _inherits(PublishButton, _Component);

      function PublishButton() {
        _classCallCheck(this, PublishButton);

        return _possibleConstructorReturn(this, _getPrototypeOf(PublishButton).apply(this, arguments));
      }

      _createClass(PublishButton, [{
        key: "publish",
        value: function publish(event) {
          this.props.published = true;
          return this._savePublished(event, true);
        }
      }, {
        key: "render",
        value: function render() {
          var _this$props = this.props,
              published = _this$props.published,
              spritemap = _this$props.spritemap;
          return IncrementalDOM.elementVoid(_clayButton["default"], null, null, "events", {
            click: this._handleButtonClicked.bind(this)
          }, "label", published ? Liferay.Language.get('unpublish-form') : Liferay.Language.get('publish-form'), "spritemap", spritemap, "ref", 'button');
        }
      }, {
        key: "toggle",
        value: function toggle(event) {
          var published = this.props.published;
          var promise;

          if (published) {
            promise = this.unpublish(event);
          } else {
            promise = this.publish(event);
          }

          return promise;
        }
      }, {
        key: "unpublish",
        value: function unpublish(event) {
          this.props.published = false;
          return this._savePublished(event, false);
        }
      }, {
        key: "_handleButtonClicked",
        value: function _handleButtonClicked(event) {
          this.toggle(event);
        }
      }, {
        key: "_savePublished",
        value: function _savePublished(event) {
          var _this$props2 = this.props,
              namespace = _this$props2.namespace,
              submitForm = _this$props2.submitForm,
              url = _this$props2.url;
          event.preventDefault();
          var form = document.querySelector("#".concat(namespace, "editForm"));

          if (form) {
            form.setAttribute('action', url);
          }

          return Promise.resolve(submitForm());
        }
      }]);

      return PublishButton;
    }(_metalJsx["default"]);

    PublishButton.PROPS = {
      namespace: _metalState.Config.string().required(),
      published: _metalState.Config.bool().value(false),
      spritemap: _metalState.Config.string().required(),
      submitForm: _metalState.Config.func().required(),
      url: _metalState.Config.string()
    };
    var _default = PublishButton;
    exports["default"] = _default;
    //# sourceMappingURL=PublishButton.es.js.map
  }
});
//# sourceMappingURL=PublishButton.es.js.map

==> com.liferay.dynamic.data.mapping.form.web-3.0.77.jar: META-INF/resources/admin/js/components/PublishButton/PublishButton.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-web@3.0.77/admin/js/components/PublishButton/PublishButton.es", ['module', 'exports', 'require', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-jsx', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;

    var _clayButton = _interopRequireDefault(require("frontend-taglib-clay$clay-button"));

    var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

    var _metalState = require("frontend-js-metal-web$metal-state");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    function _possibleConstructorReturn(self, call) {
      if (call && (_typeof(call) === "object" || typeof call === "function")) {
        return call;
      }return _assertThisInitialized(self);
    }

    function _assertThisInitialized(self) {
      if (self === void 0) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
      }return self;
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };return _getPrototypeOf(o);
    }

    function _inherits(subClass, superClass) {
      if (typeof superClass !== "function" && superClass !== null) {
        throw new TypeError("Super expression must either be null or a function");
      }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
        o.__proto__ = p;return o;
      };return _setPrototypeOf(o, p);
    }

    var PublishButton = /*#__PURE__*/function (_Component) {
      _inherits(PublishButton, _Component);

      function PublishButton() {
        _classCallCheck(this, PublishButton);

        return _possibleConstructorReturn(this, _getPrototypeOf(PublishButton).apply(this, arguments));
      }

      _createClass(PublishButton, [{
        key: "publish",
        value: function publish(event) {
          this.props.published = true;
          return this._savePublished(event, true);
        }
      }, {
        key: "render",
        value: function render() {
          var _this$props = this.props,
              published = _this$props.published,
              spritemap = _this$props.spritemap;
          return IncrementalDOM.elementVoid(_clayButton.default, null, null, "events", {
            click: this._handleButtonClicked.bind(this)
          }, "label", published ? Liferay.Language.get('unpublish-form') : Liferay.Language.get('publish-form'), "spritemap", spritemap, "ref", 'button');
        }
      }, {
        key: "toggle",
        value: function toggle(event) {
          var published = this.props.published;
          var promise;

          if (published) {
            promise = this.unpublish(event);
          } else {
            promise = this.publish(event);
          }

          return promise;
        }
      }, {
        key: "unpublish",
        value: function unpublish(event) {
          this.props.published = false;
          return this._savePublished(event, false);
        }
      }, {
        key: "_handleButtonClicked",
        value: function _handleButtonClicked(event) {
          this.toggle(event);
        }
      }, {
        key: "_savePublished",
        value: function _savePublished(event) {
          var _this$props2 = this.props,
              namespace = _this$props2.namespace,
              submitForm = _this$props2.submitForm,
              url = _this$props2.url;
          event.preventDefault();
          var form = document.querySelector("#".concat(namespace, "editForm"));

          if (form) {
            form.setAttribute('action', url);
          }

          return Promise.resolve(submitForm());
        }
      }]);

      return PublishButton;
    }(_metalJsx.default);

    PublishButton.PROPS = {
      namespace: _metalState.Config.string().required(),
      published: _metalState.Config.bool().value(false),
      spritemap: _metalState.Config.string().required(),
      submitForm: _metalState.Config.func().required(),
      url: _metalState.Config.string()
    };
    var _default = PublishButton;
    exports.default = _default;
    //# sourceMappingURL=PublishButton.es.js.map
  }
});
//# sourceMappingURL=PublishButton.es.js.map
